@@ -61,18 +61,21 @@ static void database_iterator_next(MicrofeedDatabaseIterator* iterator);
 static void database_index_iterator_next(MicrofeedDatabaseIterator* iterator);
 	
 MicrofeedDatabaseEnvironment* microfeed_database_environment_new(const char* name, const char* directory) {
-	MicrofeedDatabaseEnvironment* database_environment;
+	MicrofeedDatabaseEnvironment* database_environment = NULL;
 
-	database_environment = microfeed_memory_allocate(MicrofeedDatabaseEnvironment);
-	if (db_env_create(&database_environment->db_env, 0) || database_environment->db_env->open(database_environment->db_env, directory, DB_CREATE | DB_THREAD | DB_PRIVATE | DB_INIT_CDB | DB_INIT_MPOOL, 0)) {
-		microfeed_memory_free(database_environment);
-		database_environment = NULL;
-	} else {
-		database_environment->reference_count = 1;
-		database_environment->mutex = microfeed_mutex_new();
-		database_environment->name = strdup(name);
-		database_environment->databases = microfeed_store_new_sorted((MicrofeedStoreCompareKeysFunction)strcmp,
-			                                                  (MicrofeedStoreGetKeyFunction)microfeed_database_get_name);	
+	if (microfeed_util_create_directory_recursively(directory)) {
+		database_environment = microfeed_memory_allocate(MicrofeedDatabaseEnvironment);
+		microfeed_util_create_directory_recursively(directory);
+		if (db_env_create(&database_environment->db_env, 0) || database_environment->db_env->open(database_environment->db_env, directory, DB_CREATE | DB_THREAD | DB_PRIVATE | DB_INIT_CDB | DB_INIT_MPOOL, 0)) {
+			microfeed_memory_free(database_environment);
+			database_environment = NULL;
+		} else {
+			database_environment->reference_count = 1;
+			database_environment->mutex = microfeed_mutex_new();
+			database_environment->name = strdup(name);
+			database_environment->databases = microfeed_store_new_sorted((MicrofeedStoreCompareKeysFunction)strcmp,
+			                                                	  (MicrofeedStoreGetKeyFunction)microfeed_database_get_name);	
+		}
 	}
 
 	return database_environment;
