@@ -21,7 +21,7 @@ typedef struct {
 		MicrofeedJson* object;
 		MicrofeedJson* array;
 		char* string;
-		int integer;
+		long long int integer;
 		double decimal;
 		int boolean;
 	};
@@ -611,7 +611,7 @@ int microfeed_json_compare_members(MicrofeedJson* json, unsigned int index1, uns
 	    member1->type == member2->type) {
 		switch (member1->type) {
 			case MICROFEED_JSON_TYPE_INTEGER:
-				retvalue = member1->integer - member2->integer;
+				retvalue = (member1->integer < member2->integer ? -1 : (member1->integer > member2->integer ? + 1 : 0));
 				break;
 			case MICROFEED_JSON_TYPE_DECIMAL:
 				retvalue = member1->decimal - member2->decimal;
@@ -678,7 +678,7 @@ static const char* member_as_string(Member* member) {
 			break;
 		case MICROFEED_JSON_TYPE_INTEGER:
 			if (!member->as_string) {
-				snprintf(buffer, 1024, "%d", member->integer);
+				snprintf(buffer, 1024, "%lld", member->integer);
 				member->as_string = strdup(buffer);
 			}
 			string = member->as_string;
@@ -721,7 +721,7 @@ static char* member_to_string(Member* member) {
 			string = microfeed_json_to_string(member->object, NULL);
 			break;
 		case MICROFEED_JSON_TYPE_INTEGER:
-			snprintf(buffer, 1024, "%d", member->integer);
+			snprintf(buffer, 1024, "%lld", member->integer);
 			string = strdup(buffer);
 			break;
 		case MICROFEED_JSON_TYPE_DECIMAL:
@@ -965,7 +965,7 @@ static Member* parse_number(char* name, const char** data, const char* end) {
 	int decimal = 0;
 	char* s;
 	double d;
-	int i;
+	long long int i;
 
 	p = *data;
 	while (p < end && strchr("0123456789.eE+-", *p)) {
@@ -981,7 +981,7 @@ static Member* parse_number(char* name, const char** data, const char* end) {
 			member->decimal = d;
 		}
 	} else {
-		if (sscanf(s, "%d", &i) == 1) {
+		if (sscanf(s, "%lld", &i) == 1) {
 			member = member_new(name, MICROFEED_JSON_TYPE_INTEGER);
 			member->integer = i;
 		}			
